## Python古诗API免费开源版
## 当前版本为1.2.0
详细的文档说明见[https://stripepython.github.io/pygushi/](https://stripepython.github.io/pygushi/)

### 安装
使用`pip`:
```shell
pip install pygushi
```
使用`git`:
```shell
git clone https://github.com/stripepython/pygushi
cd pygushi
python setup.py install
```